@@ -124,14 +124,14 @@ async def finalize_validator_proposal(keypair, log_level: int = 0):
 @click.argument('mint_id')
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
-async def allocate_gem(mint_id, keypair, log_level: int = 0):
+async def process_allocate_gem(mint_id, keypair, log_level: int = 0):
     log_level = int(log_level)
     client = AsyncClient(rpc_url.target_network)
     client_state = await client.is_connected()
     print("Client is connected" if client_state else "Client is Disconnected")
     payer_keypair = parse_keypair_input(f"./{keypair}")
     mint_pubkey = parse_pubkey_input(mint_id)
-    t_dets = await allocate_gem(payer_keypair, mint_pubkey, client, log_level)
+    t_dets = await allocate_sol(payer_keypair, mint_pubkey, client, log_level)
     print(t_dets)
     await client.close()
 
@@ -139,14 +139,14 @@ async def allocate_gem(mint_id, keypair, log_level: int = 0):
 @click.argument('mint_id')
 @click.option('--keypair', default = 'keypair.json')
 @click.option('--log_level', default = '2')
-async def deallocate_gem(mint_id, keypair, log_level: int = 0):
+async def process_deallocate_gem(mint_id, keypair, log_level: int = 0):
     log_level = int(log_level)
     client = AsyncClient(rpc_url.target_network)
     client_state = await client.is_connected()
     print("Client is connected" if client_state else "Client is Disconnected")
     payer_keypair = parse_keypair_input(f"./{keypair}")
     mint_pubkey = parse_pubkey_input(mint_id)
-    t_dets = await deallocate_gem(payer_keypair, mint_pubkey, client, log_level)
+    t_dets = await deallocate_sol(payer_keypair, mint_pubkey, client, log_level)
     print(t_dets)
     await client.close()
 
@@ -362,6 +362,7 @@ entry.add_command(finalize_rebalancing)
 entry.add_command(ingl)
 entry.add_command(close_val_proposal)
 entry.add_command(process_vote_account_rewards)
+
 entry.add_command(process_create_vote_account)
 entry.add_command(get_vote_pubkey)
 entry.add_command(find_vote_key)
